Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(836)

Unified Diff: mojo/shell/package_manager/capability_filter_content_handler_unittest.cc

Issue 1679573002: Move shell interfaces into the shell.mojom namespace. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@delegate
Patch Set: . Created 4 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « mojo/shell/package_manager.h ('k') | mojo/shell/package_manager/content_handler_connection.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: mojo/shell/package_manager/capability_filter_content_handler_unittest.cc
diff --git a/mojo/shell/package_manager/capability_filter_content_handler_unittest.cc b/mojo/shell/package_manager/capability_filter_content_handler_unittest.cc
index 96bf798a8c98852cde15e2621f6d3e0607fd801b..2268a7e9bc15ab439ae65bdff977671a11f3cfe3 100644
--- a/mojo/shell/package_manager/capability_filter_content_handler_unittest.cc
+++ b/mojo/shell/package_manager/capability_filter_content_handler_unittest.cc
@@ -78,8 +78,8 @@ class TestPackageManager : public PackageManagerImpl {
};
class TestContentHandler : public ApplicationDelegate,
- public InterfaceFactory<ContentHandler>,
- public ContentHandler {
+ public InterfaceFactory<mojom::ContentHandler>,
+ public mojom::ContentHandler {
public:
TestContentHandler() : app_(nullptr) {}
~TestContentHandler() override {}
@@ -90,19 +90,19 @@ class TestContentHandler : public ApplicationDelegate,
app_ = app;
}
bool AcceptConnection(ApplicationConnection* connection) override {
- connection->AddService<ContentHandler>(this);
+ connection->AddService<mojom::ContentHandler>(this);
return true;
}
- // Overridden from InterfaceFactory<ContentHandler>:
+ // Overridden from InterfaceFactory<mojom::ContentHandler>:
void Create(ApplicationConnection* connection,
- InterfaceRequest<ContentHandler> request) override {
+ InterfaceRequest<mojom::ContentHandler> request) override {
bindings_.AddBinding(this, std::move(request));
}
// Overridden from ContentHandler:
void StartApplication(
- InterfaceRequest<Application> application,
+ InterfaceRequest<mojom::Application> application,
URLResponsePtr response,
const Callback<void()>& destruct_callback) override {
scoped_ptr<ApplicationDelegate> delegate(new test::TestApplication);
@@ -113,7 +113,7 @@ class TestContentHandler : public ApplicationDelegate,
}
ApplicationImpl* app_;
- WeakBindingSet<ContentHandler> bindings_;
+ WeakBindingSet<mojom::ContentHandler> bindings_;
ScopedVector<ApplicationDelegate> embedded_app_delegates_;
ScopedVector<ApplicationImpl> embedded_apps_;
« no previous file with comments | « mojo/shell/package_manager.h ('k') | mojo/shell/package_manager/content_handler_connection.h » ('j') | no next file with comments »
@@ -90,19 +90,19 @@ class TestContentHandler : public ApplicationDelegate,
bindings_.AddBinding(this, std::move(request));
}
- // Overridden from ContentHandler:
+ // Overridden from mojom::ContentHandler:
void StartApplication(

Powered by Google App Engine
This is Rietveld 408576698